@@ -29,8 +29,13 @@
 #include <gtk/gtk.h>
 
 #ifdef HAVE_CLUTTER
+#include <cogl/cogl.h>
 #include <clutter/clutter.h>
 #include <clutter-gtk/clutter-gtk.h>
+
+#ifndef CLUTTER_GTK_CHECK_VERSION
+#define CLUTTER_GTK_CHECK_VERSION(a,b,c) (0)
+#endif
 #endif
 
 #ifdef HAVE_HILDON
@@ -58,6 +63,7 @@
 #include "conf.h"
 #include "game.h"
 #include "window.h"
+#include "util.h"
 
 #if 0
 /* String reserve */
@@ -76,29 +82,6 @@ typedef struct {
 #endif /* HAVE_HILDON */
 } AppData;
 
-static char *
-variation_to_game_file (const char *variation)
-{
-  char *game_file, *s;
-
-  game_file = g_ascii_strdown (variation, -1);
-
-  /* Replace dangerous characters: '.' (as in "..") and '/' */
-  g_strdelimit (game_file, "." G_DIR_SEPARATOR_S, '\0');
-  g_strdelimit (game_file, NULL, '_');
-
-  if (game_file[0] == '\0') {
-    g_free (game_file);
-    return NULL;
-  }
-
-  /* Add the suffix */
-  s = g_strconcat (game_file, ".scm", NULL);
-  g_free (game_file);
-
-  return s;
-}
-
 #ifdef WITH_SMCLIENT
 
 static void
@@ -289,9 +272,14 @@ main_prog (void *closure, int argc, char *argv[])
 #ifdef WITH_SMCLIENT
   g_option_context_add_group (option_context, egg_sm_client_get_option_group ());
 #endif /* WITH_SMCLIENT */
+
 #ifdef HAVE_CLUTTER
+  g_option_context_add_group (option_context, cogl_get_option_group ());
   g_option_context_add_group (option_context, clutter_get_option_group_without_init ());
+#if CLUTTER_GTK_CHECK_VERSION (0, 90, 0)
+  g_option_context_add_group (option_context, gtk_clutter_get_option_group ());
 #endif
+#endif /* HAVE_CLUTTER */
 
 #if defined(HAVE_HILDON) && defined(HAVE_MAEMO_5)
   {
@@ -317,12 +305,14 @@ main_prog (void *closure, int argc, char *argv[])
   }
 
 #ifdef HAVE_CLUTTER
+#if !CLUTTER_GTK_CHECK_VERSION (0, 90, 0)
   if (gtk_clutter_init_with_args (NULL, NULL, NULL, NULL, NULL, &error) != CLUTTER_INIT_SUCCESS) {
     g_printerr ("Failed to initialise clutter: %s\n", error->message);
     g_error_free (error);
     goto cleanup;
   }
 #endif
+#endif /* HAVE_CLUTTER */
 
 #ifdef HAVE_MAEMO
   data.program = HILDON_PROGRAM (hildon_program_get_instance ());
@@ -341,7 +331,7 @@ main_prog (void *closure, int argc, char *argv[])
     char *game_file = NULL;
 
     if (data.variation[0] != '\0') {
-      game_file = variation_to_game_file (data.variation);
+      game_file = aisleriot_variation_to_game_file (data.variation);
     }
 
     g_free (data.variation);
